"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const pipcook_core_1 = require("@pipcook/pipcook-core");
const path = __importStar(require("path"));
const assert = __importStar(require("assert"));
const OSS = require('ali-oss');
const shell = require('shelljs');
const uuidv1 = require('uuid/v1');
const fs = require('fs-extra');
const detectionDetectronModelDeploy = (data, model, args) => __awaiter(void 0, void 0, void 0, function* () {
    const { easName = '', cpus = 2, memory = 4000, ossConfig = {}, ossDir = '' } = args || {};
    const packagePath = path.join(process.cwd(), '.temp', uuidv1());
    fs.ensureDirSync(path.join(packagePath, easName));
    try {
        // get detectron env
        const envUrl = 'http://ai-sample.oss-cn-hangzhou.aliyuncs.com/eas-pack/';
        const zipPath = path.join(packagePath, easName, 'ENV.zip');
        yield pipcook_core_1.downloadZip(envUrl + 'ENV.zip', zipPath);
        yield pipcook_core_1.unZipData(zipPath, path.join(packagePath, easName));
        fs.removeSync(zipPath);
        // write app.json
        const app = {
            processor_path: 'http://' + ossConfig.bucket + '.' + ossConfig.region + '.aliyuncs.com/' + ossDir + '/' + easName + '.tar.gz',
            processor_entry: './app.py',
            processor_type: "python",
            name: easName,
            generate_token: "true",
            metadata: {
                cpu: cpus,
                memory: memory,
                "rpc.keepalive": 60000
            }
        };
        fs.outputFileSync(path.join(packagePath, easName, 'app.json'), JSON.stringify(app));
        // copy config
        const configPath = model.extraParams.detectronConfigPath;
        fs.copySync(configPath, path.join(packagePath, easName, 'config'));
        // copy model
        const modelPath = model.extraParams.modelPath;
        fs.copySync(modelPath, path.join(packagePath, easName, 'output', 'model_final.pth'));
        // copy app.py
        yield pipcook_core_1.downloadZip(envUrl + 'app.py', path.join(packagePath, easName, 'app.py'));
        // save label map
        fs.writeFileSync(path.join(packagePath, easName, 'label.json'), JSON.stringify(data.metaData.label.valueMap));
        // package the whole content
        yield pipcook_core_1.compressTarFile(path.join(packagePath, easName), path.join(packagePath, easName + '.tar.gz'));
        // upload to oss
        const client = OSS(ossConfig);
        yield client.put(path.join(ossDir, easName + '.tar.gz'), path.join(packagePath, easName + '.tar.gz'), { timeout: 60000000 });
        // create service
        assert.ok(shell.which('eascmd'), 'please install eascmd first');
        if (shell.exec('eascmd create ' + path.join(packagePath, easName, 'app.json')).code !== 0) {
            shell.echo('Error: create service' + easName + 'failed');
            shell.exit(1);
        }
    }
    finally {
        fs.removeSync(packagePath);
    }
});
exports.default = detectionDetectronModelDeploy;
//# sourceMappingURL=index.js.map